# ironArray Community Edition

## What it is

ironArray Community is the open source version of [ironArray](https://ironarray.io).  It has been developed to mimic the same API than h5py or Zarr.  It implements the support for simple and double floating-point data using a metalayer. With the community edition of ironArray you can extract slices from floating-point datasets in a simple way!

For more info, see the docs at: https://ironarray.io/docs/iarray-community/


## Installing

ironArray Community is a pure Python package, so it can easily be installed for any platform.
You can install binary packages from PyPi using `pip`:

```console
    python -m pip install iarray-community
```

----

**Have fun!**

The ironArray Team
